#!/bin/bash

function interface_menu () {

	local rc
	local num="$1"
	local name
	local choice
	local menu_options
	local menu_size


	# Initialize common variables
        # Operation mode is WANPIPE by default
        # Protocol Status is unconfigured by default
        # IP Stataus is unconfigured by default

	if [ -z "${OP_MODE[$num]}" ]; then
		OP_MODE[$num]="WANPIPE"
	fi
	if [ -z "${PROT_STATUS[$num]}" ]; then
		PROT_STATUS[$num]="Unconfigured"
	fi

	if [ -z "${IP_STATUS[$num]}" ]; then
		IP_STATUS[$num]="Unconfigured"
	fi

	# For each protocol createa special menu
	case $PROTOCOL in

	WAN_FR) 	
		name="fr"${DLCI_NUM[$num]}	
		if [ -z ${DLCI_NUM[$num]} ]; then
	menu_options="'get_dlci'           'DLCI Number  --------> ${DLCI_NUM[$num]}' 2> menu.tmp.$$"
	menu_size=1
		else
	menu_options="'get_dlci'           'DLCI Number  -------------> ${DLCI_NUM[$num]}' \
		      'get_interface_name' 'Interface Name -----------> ${IF_NAME[$num]}' \
		      'get_operation_mode' 'Operation Mode -----------> ${OP_MODE[$num]}' \
		      'prot_inter_setup'   'DLCI Protocol Setup ------> ${PROT_STATUS[$num]}' \\"
			echo "$menu_options" > dev_options.$$

			if [ ${OP_MODE[$num]} = WANPIPE ]; then	
	menu_options="'ip_setup'           'DLCI IP Address Setup ----> ${IP_STATUS[$num]}' \\"
				echo "$menu_options" >> dev_options.$$
			fi

			menu_options="2> menu.tmp.$$" 
			echo "$menu_options" >> dev_options.$$

			menu_options=`cat dev_options.$$`
			rm -f dev_options.$$
			menu_size=5
		fi
			;;
	WAN_CHDLC)
	 	name=chdlc
		if [ -z ${IF_NAME[$num]} ]; then
			IF_NAME[$num]="wp"$DEVICE_NUM"_"$name	
		fi
	menu_options="'get_interface_name' 'Interface Name -----------> ${IF_NAME[$num]}' \
		      'get_operation_mode' 'Operation Mode -----------> ${OP_MODE[$num]}' \
		      'prot_inter_setup'   'CHDLC Protocol Setup -----> ${PROT_STATUS[$num]}' \\"
		echo "$menu_options" > dev_options.$$	

		if [ ${OP_MODE[$num]} = WANPIPE ]; then	
	menu_options="'ip_setup'           'IP Address Setup ---------> ${IP_STATUS[$num]}' \\"
			echo "$menu_options" >> dev_options.$$
		fi

		menu_options="2> menu.tmp.$$" 
		echo "$menu_options" >> dev_options.$$

		menu_options=`cat dev_options.$$`
		rm -f dev_options.$$
		menu_size=4

			;;
	WAN_PPP)
	 	name=ppp
		if [ -z ${IF_NAME[$num]} ]; then
			IF_NAME[$num]="wp"$DEVICE_NUM"_"$name	
		fi
	menu_options="'get_interface_name' 'Interface Name -----------> ${IF_NAME[$num]}' \
		      'get_operation_mode' 'Operation Mode -----------> ${OP_MODE[$num]}' \
		      'prot_inter_setup'   'PPP Protocol Setup -------> ${PROT_STATUS[$num]}' \
		      'ip_setup'           'IP Address Setup ---------> ${IP_STATUS[$num]}' 2> menu.tmp.$$"
		menu_size=4
			;;

	WAN_X25)
		CH_TYPE[$num]=${CH_TYPE[$num]:-SVC}

		#If X25API is to be used as LAPB HDLC only than,
       	 	#only interface allowed is PVC.
		if [ ! -z "$LAPB_HDLC_ONLY" ]; then
			if [ $LAPB_HDLC_ONLY = YES ]; then
				CH_TYPE[$num]="PVC"
			fi
		else
			LAPB_HDLC_ONLY="NO"	
		fi

		X25_ADDR[$num]=${X25_ADDR[$num]:-1}	
			

		name=svc
		if [ -z ${IF_NAME[$num]} ]; then
			IF_NAME[$num]="wp"$DEVICE_NUM"_"$name$num	
		fi

	menu_options="'get_interface_name' 'Interface Name -----------> ${IF_NAME[$num]}' \
		      'get_operation_mode' 'Operation Mode -----------> ${OP_MODE[$num]}' \
		      'get_channel_type'   'Channel Type -------------> ${CH_TYPE[$num]}' \
		      'get_x25_address'    'X25 Address/LCN ----------> ${X25_ADDR[$num]}' \\"

		echo "$menu_options" > dev_options.$$

		if [ ${CH_TYPE[$num]} = SVC ]; then
	menu_options="'prot_inter_setup'   'X25 Protocol Setup -------> ${PROT_STATUS[$num]}' \\"
			echo "$menu_options" >> dev_options.$$	
		fi
	
		if [ ${OP_MODE[$num]} = WANPIPE ]; then	
	menu_options="'ip_setup'           'IP Address Setup ---------> ${IP_STATUS[$num]}' \\"
			echo "$menu_options" >> dev_options.$$
		fi

	menu_options="2> menu.tmp.$$" 
	echo "$menu_options" >> dev_options.$$

	menu_options=`cat dev_options.$$`
	rm -f dev_options.$$

		menu_size=6;
			;;
	esac


	#Now that the menu is created, set the menu instructions
        #and print the menu to the screen. Once the menu is 
        #printed wait for user input.

	menu_instr="	Please specify interface parameters below.	\
									"

	menu_name "INTERFACE $num DEFINITION" "$menu_options" "$menu_size" "$menu_instr" "$BACK"
	rc=$?

	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$


	#We received user input, now take appropriate action
	case $rc in
		0)	case $choice in
			get_interface_name)
				get_string "Please specify a Network Interface Name" "$name"
				IF_NAME[$num]="wp"$DEVICE_NUM"_"$($GET_RC)
				;;
			get_dlci)
				get_integer "Please specify a DLCI number" "16" "16" "16000" "interface_menu_help get_dlci"

				DLCI_NUM[$num]=$($GET_RC)
				IF_NAME[$num]="wp"$DEVICE_NUM"_fr"${DLCI_NUM[$num]}
				name="fr"${DLCI_NUM[$num]}
				;;
			get_x25_address)
				get_integer "Please specify a X25 Address for SVC or LCN number for PVC. To accept all calls leave blank (SVC only)." "1" "1" "1000000" "interface_menu_help get_x25_address"
				X25_ADDR[$num]=$($GET_RC)
				;;
			 
			*)
				$choice "$num"    #Choice is a command 
				;;
			esac
			return 0 
			;;

		1) 	
			#EXIT to previous screen
			return 1
			;;

		2)	
			#HELP
			choice=${choice%\"*\"}
			choice=${choice// /}
			interface_menu_help $choice
			return 0
			;;
		*)	
			#EXIT to previous screen
			return 1
	esac

}

#============================================================
# get_device_setup
#
# 	General Hardware Setup
#	All [wanpipe#] variables configued in the area
#	
#============================================================
function gen_device_setup () {

	local rc
	local choice
	local menu_options
	local menu_options0
	local menu_options1
	local menu_options2
	local menu_opt_prot
	local frim_name
	local menu_size

	if [ -z "$DEVICE_TYPE" ]; then
		DEVICE_TYPE=S514
	fi

	#Setup protocol specific menues

	menu_options0="'get_device_type'       'Adapter Type ---> $DEVICE_TYPE' \\"

	if [ $DEVICE_TYPE = S514 ]; then
		menu_options1="'get_s514_cpu'  'S514CPU --------> $S514CPU' \
			      'get_s514_slot' 'PCISLOT --------> $PCISLOT' \\"
	else
		menu_options1="'get_s508_io'   'IOPORT ---------> $IOPORT' \
			      'get_s508_irq'  'IRQ ------------> $IRQ' \\"
	fi
	
	menu_options2="'get_firmware'  'Firmware Module-> $FIRMWARE' \
		       'get_memory'    'Memory Addr ----> $MEMORY' \
		       'get_interface' 'Interface ------> $INTERFACE' \
		       'get_clocking'  'Clocking -------> $CLOCKING' \
		       'get_baudrate'  'Baud Rate ------> $BAUDRATE' \
		       'get_mtu'       'MTU  -----------> $MTU' \
		       'get_udpport'   'UDP Port -------> $UDPPORT' \
		       'get_ttl'       'Time to live ---> $TTL' \\"

	case $PROTOCOL in

	WAN_FR)
	menu_opt_prot="'get_station'   'Station --------> $STATION' \
		       'get_signal'    'Signalling -----> $SIGNAL' \
		       'get_T391'      'T391 -----------> $T391' \
		       'get_T392'      'T392 -----------> $T392' \
		       'get_N391'      'N391 -----------> $N391' \
		       'get_N392'      'N392 -----------> $N392' \
		       'get_N393'      'N393 -----------> $N393' \\"
		echo "$menu_options0" > dev_options.$$
		echo "$menu_options1" >> dev_options.$$
		echo "$menu_options2" >> dev_options.$$
		echo "$menu_opt_prot" >> dev_options.$$
		menu_size=13
		firm_name=fr514.sfm
		;;

	WAN_CHDLC)
		menu_opt_prot="'get_commport'  'Comm Port ------> $COMMPORT' \\" 
		echo "$menu_options0" > dev_options.$$
		echo "$menu_options1" >> dev_options.$$
		echo "$menu_opt_prot" >> dev_options.$$

		if [ $DEVICE_TYPE = S514 ]; then
			menu_opt_prot="'get_rec_only' 'Receive Only ---> $REC_ONLY' \\"
			echo "$menu_opt_prot" >> dev_options.$$
		fi	
		echo "$menu_options2" >> dev_options.$$
		
		menu_size=13
		firm_name=cdual514.sfm
		;;
	
	WAN_PPP)
	menu_opt_prot="'get_ipmode'    'IP Mode --------> $IPMODE' \\"
		echo "$menu_options0" > dev_options.$$
		echo "$menu_options1" >> dev_options.$$
		echo "$menu_options2" >> dev_options.$$
		echo "$menu_opt_prot" >> dev_options.$$
		menu_size=12
		firm_name=ppp514.sfm
		;;
	WAN_X25)
	menu_opt_prot="'get_hdlc_station' 'Station --------> $STATION' \
		       'get_low_pvc'   	  'Lowest PVC -----> $LOW_PVC' \
		       'get_high_pvc'     'Highest PVC ----> $HIGH_PVC' \
		       'get_low_svc'      'Lowest SVC -----> $LOW_SVC' \
		       'get_high_svc'     'Highest SVC-----> $HIGH_SVC' \
		       'get_hdlc_win'     'HDLC Window ----> $HDLC_WIN' \
		       'get_packet_win'   'Packet Window --> $PACKET_WIN' \
		       'get_ccitt'        'CCITT Compat. --> $CCITT' \
		       'get_hdlc_only'    'LAPB HDLC Only -> $LAPB_HDLC_ONLY' \
		       'get_logging'      'Call Logging ---> $CALL_LOGGING' \
		       'get_T1'      	  'T1 -------------> $X25_T1' \
		       'get_T2'      	  'T2 -------------> $X25_T2' \
		       'get_T4'      	  'T4 -------------> $X25_T4' \
		       'get_N2'      	  'N2 -------------> $X25_N2' \
		       'get_T10_T20'   	  'T10_T20 --------> $X25_T10_T20' \
		       'get_T11_T21'   	  'T11_T21 --------> $X25_T11_T21' \
		       'get_T12_T22'   	  'T12_T22 --------> $X25_T12_T22' \
                       'get_T13_T23'   	  'T13_T23 --------> $X25_T13_T23' \
		       'get_T16_T26'   	  'T16_T26 --------> $X25_T16_T26' \
		       'get_T16_T26'   	  'T16_T26 --------> $X25_T16_T26' \
		       'get_T28'   	  'T28 ------------> $X25_T28' \
		       'get_R10_R20'   	  'R10_R20 --------> $X25_R10_R20' \
		       'get_R12_R22'   	  'R12_R22 --------> $X25_R12_R22' \
		       'get_R13_R23'   	  'R13_R23 --------> $X25_R13_R23' \\"		
		echo "$menu_options0" > dev_options.$$
		echo "$menu_options1" >> dev_options.$$
		echo "$menu_options2" >> dev_options.$$
		echo "$menu_opt_prot" >> dev_options.$$
		menu_size=13
		firm_name=x25_514.sfm
		;;
	*) 
		echo "ERROR, Protocol not specified"
		return 1
		;;
	esac

	echo " 2> menu.tmp.$$" >> dev_options.$$


	#The menues are completed, now print the menu to the user and 
        #wait for result

	menu_options=`cat dev_options.$$` 
	rm -f dev_options.$$

	menu_instr="	Physical Link: wanpipe$DEVICE_NUM Configuration  \
					"

	menu_name "WANPIPE$DEVICE_NUM HARDWARE CONFIGURATION" "$menu_options" "$menu_size" "$menu_instr" "$BACK" 20 50 
	rc=$?
	
	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$


	#We got the result, take appropriate action 
	case $rc in
		0)	case $choice in
				get_s514_slot) 
					get_integer "Please specify a PCI Slot Number (default 0)" "0" "0" "100" "device_setup_help get_s514_slot" 
					PCISLOT=$($GET_RC)      #Choice is a command 
					;;
				get_udpport)
					get_integer "Please specify a UDP Port (default 9000)" "9000" "9000" "9999" "device_setup_help get_udpport"
					UDPPORT=$($GET_RC)
					;;
				get_T391)
					get_integer "Please specify the T391 timer (default 10)" "10" "5" "30" "device_setup_help get_T391"
					T391=$($GET_RC)
					;;
				get_T392)
					get_integer "Please specify the T392 timer (default 16)" "16" "5" "30" "device_setup_help get_T392"
					T392=$($GET_RC)
					;;
				get_N391)
					get_integer "Please specify the N391 timer (default 2)" "2" "1" "255" "device_setup_help get_N391"
					N391=$($GET_RC)
					;;	
				get_N392)
					get_integer "Please specify the N392 timer (default 3)" "3" "1" "10" "device_setup_help get_N392"
					N392=$($GET_RC)
					;;
				get_N393)
					get_integer "Please specify the N393 timer (default 4)" "4" "1" "10" "device_setup_help get_N393"
					N393=$($GET_RC)
					;;
				get_ttl)
					get_integer "Please specify the TTL value (default 255)" "255" "1" "255" "device_setup_help get_ttl"
					TTL=$($GET_RC)
					;;
			        get_s508_irq)
					get_integer "Please specify an IRQ number" "7" "1" "15" "device_setup_help get_s508_irq"
					IRQ=$($GET_RC)
					;;
				get_T1)
					get_integer "Please specify the HDLC T1 Timer value" "3" "1" "30" "device_setup_help get_T1"
					X25_T1=$($GET_RC)
					;;
				get_T2)
					if [ $X25_T1 -gt 0 ]; then
						t2_max=$((X25_T1-1))
					else
						t2_max=0
					fi
					get_integer "Please specify the HDLC T2 Timer value. (Must be lower than T1=$X25_T1)." "0" "0" "$t2_max" "device_setup_help get_T2"
					X25_T2=$($GET_RC)
					;;
				get_T4)
					get_integer "Please specify the HDLC T4 Timer value" "240" "0" "240" "device_setup_help get_T4"
					X25_T4=$($GET_RC)
					;;
				
				get_N2)
					get_integer "Please specify the HDLC N2 Timer value" "10" "1" "30" "device_setup_help get_N2"
					X25_N2=$($GET_RC)
					;;

				get_T10_T20)
					get_integer "Please specify the HDLC T10_T20 Timer value" "30" "1" "255" "device_setup_help get_T10_T20"
					X25_T10_T20=$($GET_RC)
					;;
				get_T11_T21)
					get_integer "Please specify the HDLC T11_T21 Timer value" "30" "1" "255" "device_setup_help get_T11_T21"
					X25_T11_T21=$($GET_RC)
					;;
				get_T12_T22)
					get_integer "Please specify the HDLC T12_T22 Timer value" "30" "1" "255" "device_setup_help get_T12_T22"
					X25_T12_T22=$($GET_RC)
					;;
				get_T13_T23)
					get_integer "Please specify the HDLC T13_T23 Timer value" "30" "1" "255" "device_setup_help get_T13_T23"
					X25_T13_T23=$($GET_RC)
					;;
				get_T16_T26)
					get_integer "Please specify the HDLC T16_T26 Timer value" "30" "1" "255" "device_setup_help get_T16_T26"
					X25_T16_T26=$($GET_RC)
					;;
				get_T28)
					get_integer "Please specify the HDLC T28 Timer value" "30" "1" "255" "device_setup_help get_T28"
					X25_T28=$($GET_RC)
					;;
				get_R10_R20)
					get_integer "Please specify the HDLC R10_R20 Timer value" "30" "0" "250" "device_setup_help get_R10_R20"
					X25_R10_20=$($GET_RC)
					;;
				get_R12_R22)
					get_integer "Please specify the HDLC R12_R22 Timer value" "30" "0" "250" "device_setup_help get_R12_R22"
					X25_R12_22=$($GET_RC)
					;;
				get_R13_R23)
					get_integer "Please specify the HDLC R13_R23 Timer value" "30" "0" "250" "device_setup_help get_R13_R23"
					X25_R13_23=$($GET_RC)
					;;
				
				get_firmware)
					while true
					do
						get_string "Specify the location of the Firmware (.sfm) module: Absolute Path" "$PROD_HOME/firmware" 
						FIRMWARE=$($GET_RC)
						if [ -d "$FIRMWARE" ]; then
							break
						else
							error "FIRMWARE"
						fi
					done
					;;
				get_baudrate)
					if [ $DEVICE_TYPE = S514 ]; then
					get_integer "Please specify the Baud Rate in bps" "1544000" "64" "4096000" "device_setup_help get_baudrate"

					else
					get_integer "Please specify the Baud Rate in bps" "1544000" "64" "2048000" "device_setup_help get_baudrate" 
					fi
					BAUDRATE=$($GET_RC)
					;;
				get_mtu)
					if [ $PROTOCOL = WAN_X25 ]; then
						dflt_mtu=1024;
					else
						dflt_mtu=1500;
					fi
					get_integer "Please specify Maximu Packet Size (MTU)" "$dflt_mtu" "128" "4098" "device_setup_help get_mtu"
					MTU=$($GET_RC)
					;;
				get_low_pvc)
					get_integer "Please specify Lowest PVC Channel" "0" "0" "100" "device_setup_help get_low_pvc"
					LOW_PVC=$($GET_RC)
					;;
				get_high_pvc)
					get_integer "Please specify Highest PVC Channel" "0" "0" "100" "device_setup_help get_high_pvc"
					HIGH_PVC=$($GET_RC)
					;;
				get_low_svc)
					get_integer "Please specify Lowest SVC Channel" "0" "0" "100" "device_setup_help get_low_svc"
					LOW_SVC=$($GET_RC)
					;;
				get_high_svc)
					get_integer "Please specify Highest SVC Channel" "0" "0" "100" "device_setup_help get_high_svc"
					HIGH_SVC=$($GET_RC)
					;;
				get_hdlc_win) 
					get_integer "Please specify HDLD Window Size" "7" "1" "7" "device_setup_help get_hdlc_win"
					HDLC_WIN=$($GET_RC)
					;;
				get_packet_win)
					get_integer "Please specify Packet Window Size" "7" "1" "7" "device_setup_help get_packet_win"
					PACKET_WIN=$($GET_RC)				
					;;

				*)	$choice     #Choice is a command 
					;;
			esac
			return 0
			;;
		2)	choice=${choice%\"*\"}
			choice=${choice// /}
			device_setup_help $choice
			return 0	
			;;
		*) 	return 1
			;;
	esac
}

function ip_setup_menu () {
	
	local ret
	local rc
	local menu_options
	local num="$1"

	if [ -z "${NMSK_IP[$num]}" ]; then
		NMSK_IP[$num]="255.255.255.255"
	fi
	if [ -z "${DEFAULT_IP[$num]}" ]; then
		DEFAULT_IP[$num]=NO
		NETWRK_IP[$num]=" "
	fi

	menu_options="'get_local_ip' 'Local IP Addr. ---------> ${L_IP[$num]}' \
		      'get_rmt_ip'   'Point-to-Point IP Addr.-> ${R_IP[$num]}' \
		      'get_netmask'  'Net Mask IP Addr. ------> ${NMSK_IP[$num]}' \
		      'get_default'  'Default Gateway --------> ${DEFAULT_IP[$num]}' 2> menu.tmp.$$"

	menu_instr="	Interface specify IP addresses supplied by your ISP \
				"
  	menu_name "${IF_NAME[$num]}: IP CONFIGURATION" "$menu_options" 4 "$menu_instr" "$BACK" 20 50 
	rc=$?
	
	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $rc in

		0) 
			case $choice in
			get_local_ip)
				get_string "Please specify the Local IP Address" "${L_IP[$num]}" "IP_ADDR" 
				L_IP[$num]=$($GET_RC)
				;;
			get_rmt_ip)
				get_string "Please specify the Point-to-Point IP Address" "${R_IP[$num]}" "IP_ADDR"
				R_IP[$num]=$($GET_RC)
				;;
			get_netmask)
				get_string "Please specify the Net Mask Addr" "${NMSK_IP[$num]}" "IP_ADDR"
				NMSK_IP[$num]=$($GET_RC)
				;;
			get_bcast)
				get_string "Please specify the Broadcast IP Address" "${BCAST_IP[$num]}" "IP_ADDR"
				BCAST_IP[$num]=$($GET_RC)
				;;
			#This is not begin used should be removed
			get_network)
				get_string "Please specify the Network IP Address" "${NETWRK_IP[$num]}" "IP_ADDR"
				NETWRK_IP[$num]=$($GET_RC)
				;;
			#This is not being used should be removed
			get_gateway)
				get_string "Please specify the Gateway IP Address" "${GATE_IP[$num]}" "IP_ADDR"
				GATE_IP[$num]=$($GET_RC)
				;;
			get_default)
				warning get_default
				if [ $? -eq 0 ]; then
					DEFAULT_IP[$num]=YES
					NETWRK_IP[$num]=0
				else
					DEFAULT_IP[$num]=NO
					NETWRK_IP[$num]=" "
				fi
				;;
			esac
			return 0
			;;
		2)	choice=${choice%\"*\"}
			choice=${choice// /}
			ip_setup_help $choice	
			return 0 
			;;
		*) return 1
			;;

	esac

}

function get_operation_mode () {

	local ret
	local menu_options
	local num="$1"

	if [ $PROTOCOL = WAN_PPP ]; then
		menu_options="'WANPIPE' 'WANPIPE' 2> menu.tmp.$$" 

	else
		menu_options="'WANPIPE' 'WANPIPE' \
			      'API' 'API' 2> menu.tmp.$$"
	fi

	menu_instr="Please select Wanpipe Operation Mode \
					"
	menu_name "OPERATION MODE CONFIGURATION" "$menu_options" 2 "$menu_instr" "$BACK"
	retval=$?

	input=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $retval in
	  	0)	OP_MODE[$num]=$input
			return 0 
			;;
	  	1) 	return 1
			;;
		2)	interface_menu_help "get_operation_mode"
			get_operation_mode $1
			;;
	  	255) 	return 1
			;;
	esac       
}


function device_init () {

	#Common
	IOPORT=${IOPORT:-0x360}
	IRQ=${IRQ:-7}
	S514CPU=${S514CPU:-A}
	PCISLOT=${PCISLOT:-0}
	INTERFACE=${INTERFACE:-V35}
       	CLOCKING=${CLOCKING:-External}
	FIRMWARE=${FIRMWARE:-$PROD_HOME/firmware}
	MEMORY=${MEMORY:-Auto}
     	BAUDRATE=${BAUDRATE:-1540000}
	if [ $PROTOCOL = WAN_X25 ]; then
		MTU=${MTU:-1024}
	else
		MTU=${MTU:-1500}
	fi
	UDPPORT=${UDPPORT:-9000}

	#PPP Specific
	IPMODE=${IPMODE:-STATIC}

	#Chdlc Specific
	COMMPORT=${COMMPORT:-PRI}
	REC_ONLY=${REC_ONLY:-NO}

	#Frame Relay Specific
	if [ $PROTOCOL = WAN_FR ]; then
		STATION=${STATION:-CPE}
	else
		STATION=${STATION:-DTE}
	fi
	SIGNAL=${SIGNAL:-ANSI}
	T391=${T391:-10}
	T392=${T392:-16}
	N391=${N391:-2}
	N392=${N392:-3}
	N393=${N393:-4}
	TTL=${TTL:-255} 

	#X25 Specific
	if [ $PROTOCOL = WAN_X25 ]; then
		LOW_PVC=${LOW_PVC:-0}
		HIGH_PVC=${HIGH_PVC:-0}
		LOW_SVC=${LOW_SVC:-0}
		HIGH_SVC=${HIGH_SVC:-0}
		HDLC_WIN=${HDLC_WIN:-7}
		PACKET_WIN=${PACKET_WIN:-7}
		CCITT=${CCITT:-1988}
		LAPB_HDLC_ONLY=${LAPB_HDLC_ONLY:-NO}
		CALL_LOGGING=${CALL_LOGGING:-YES}
		X25_T1=${X25_T1:-3}
		X25_T2=${X25_T2:-0}
		X25_T4=${X25_T4:-240}
		X25_N2=${X25_N2:-10}
		X25_T10_T20=${X25_T10_T20:-30}
		X25_T11_T21=${X25_T11_T21:-30}
		X25_T12_T22=${X25_T12_T22:-30}
		X25_T13_T23=${X25_T13_T23:-30}
		X25_T16_T26=${X25_T16_T26:-30}
		X25_T16_T26=${X25_T16_T26:-30}
		X25_T28=${X25_T28:-30}
		X25_R10_R20=${X25_R10_R20:-5}
		X25_R12_R22=${X25_R12_R22:-5}
		X25_R13_R23=${X25_R13_R23:-5}
	fi
}


function get_multicast () {

	local menu_options
	local rc
	local choice
	local num="$1"

	menu_options="'NO'  'Disable Multicast (default)' \
		      'YES' 'Enable Multicast' 2> menu.tmp.$$"


	menu_instr="Enable or Disable Multicast Option \
						"

	menu_name "${IF_NAME[$num]}: MULTICAST CONFIGURATION" "$menu_options" 2 "$menu_instr" "$BACK"
	rc=$?

	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $rc in
		0) 	MULTICAST[$num]=$choice     #Choice is a command 
			return 0
			;;
		2)	interface_setup_help "get_multicast"
			get_multicast "$1"
			;;
		*) 	return 1
			;;
	esac

}

function get_s514_cpu () {
 
	local menu_options
	local rc
	local choice

	menu_options="'A' 'CPU A' \
		      'B' 'CPU B' 2> menu.tmp.$$"


	menu_instr="Please select S514 PCI, CPU Number \
						"

	menu_name "S514 CPU CONFIGURATION" "$menu_options" 2 "$menu_instr" "$BACK"
	rc=$?

	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $rc in
		0) 	S514CPU=$choice     #Choice is a command 
			return 0
			;;
		2)	device_setup_help "get_s514_cpu"
			get_s514_cpu
			;;
		*) 	return 1
			;;
	esac
}

function get_s508_io () {
 
	local menu_options
	local rc
	local choice

	menu_options="'0x360' '0x360-0x363 Io Range (default)' \
		      '0x390' '0x390-0x393 Io Range' \
		      '0x380' '0x380-0x383 Io Range' \
		      '0x350' '0x350-0x352 Io Range' \
		      '0x300' '0x300-0x393 Io Range' \
		      '0x280' '0x280-0x283 Io Range' \
		      '0x270' '0x270-0x273 Io Range' \
		      '0x250' '0x250-0x253 Io Range' 2> menu.tmp.$$"

	menu_instr="Please select S508, IO Range. Refer to hardware manual \
								"
	menu_name "S508 IO PORT CONFIGURATION" "$menu_options" 7 "$menu_instr" "$BACK"
	rc=$?

	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $rc in
		0) 	IOPORT=$choice     #Choice is a command 
			return 0
			;;
		2)  	device_setup_help "get_s508_io"
			get_s508_io
			;;
		*) 	return 1
			;;
	esac
}

	
function get_interface () {
 
	local menu_options
	local rc
	local choice


	if [ -z "$COMMPORT" ]; then
		COMMPORT=PRI
	fi

	if [ $DEVICE_TYPE = S508 -a  $PROTOCOL = WAN_CHDLC -a  $COMMPORT = SEC ];
	then
		menu_options="'RS232' 'RS232 Interface' 2> menu.tmp.$$"
	else
		menu_options="'V35' 'V35 Interface' \
		      	      'RS232' 'RS232 Interface' 2> menu.tmp.$$"

	fi

	menu_instr="Please select $DEVICE_TYPE, Interface Type \
						"

	menu_name "WAN INTERFACE CONFIGURATION" "$menu_options" 2 "$menu_instr" "$BACK"
	rc=$?

	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $rc in
		0) 	INTERFACE=$choice     #Choice is a command 
			return 0
			;;
		2) 	device_setup_help "get_interface"
			get_interface
			;;
		*) 	return 1
			;;
	esac
}


function get_clocking () {
 
	local menu_options
	local rc
	local choice


	menu_options="'External' 'External Clocking' \
	      	      'Internal' 'Internal Clocking' 2> menu.tmp.$$"

	menu_instr="Please specify a Clocking Source \
						"

	menu_name "WANPIPE$DEVICE_NUM CLOCKING CONFIGURATION" "$menu_options" 2 "$menu_instr" "$BACK"
	rc=$?

	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $rc in
		0) 	CLOCKING=$choice     #Choice is a command 
			return 0
			;;
		2)	device_setup_help "get_clocking"
			get_clocking
			;;
		*) 	return 1
			;;
	esac
}

function get_memory () {
 
	local menu_options
	local rc
	local choice


	menu_options="'Auto' 	   'Auto Detect Memory (Default)' \
                      'get_string' 'Custom Setup' 2> menu.tmp.$$"


	menu_instr="Please specify the wanpipe$DEVICE_NUM physical Memory Address. 					\
				"

	menu_name "WANPIPE MEM-ADDR CONFIGURATION" "$menu_options" 2 "$menu_instr" "$BACK"
	rc=$?

	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $rc in
		0) 	if [ $choice = get_string ]; then
				$choice "Please specify Memory Address in Hex" "0xEE000" 
				MEMORY=$($GET_RC)
			else
				MEMORY=$choice     #Choice is a command 
			fi
			return 0
			;;
		2)	device_setup_help "get_memory"
			get_memory
			;;
		*) 	return 1
			;;
	esac
}

function get_device_type () {

	local choice
	local rc

	menu_options="'S514' 'S514 PCI Card' \
		      'S508' 'S508 ISA Card' 2> menu.tmp.$$"

	menu_instr="Please specify Sangoma Card Type. Refer to User Manual \
									"

	menu_name "SANGOMA CARD TYPE" "$menu_options" 2 "$menu_instr" "$BACK"
	rc=$?

	choice=`cat menu.tmp.$$`
	rm -f menu.tmp.$$

	case $rc in
		0) 	DEVICE_TYPE=$choice     #Choice is a command 
			;;
		2)	device_setup_help "get_device_type" 
			get_device_type
			;;
		*) 	return 1
			;;
	esac

}

function check_config () {

	local num

	if [ -z "$DEVICE_NUM" ]; then
		error "DEVICE_NUM" 
		return 1
	fi
	
	if [ -z "$NUM_OF_INTER" ]; then
		error "NUM_OF_INTER" 
		return 1
	fi

	if [ $NUM_OF_INTER -eq 0 ]; then
		error "NUM_OF_INTER" 
		return 1
	fi

	if [ -z "$DEVICE_TYPE" ]; then
		error "DEVICE_TYPE" 
		return 1
	fi

	num=0
	while [ $num -ne $NUM_OF_INTER ];
	do
		num=$((num+1))
		if [ -z "${IF_NAME[$num]}" ]; then
			error "IF_NAME" $num
			return 1
		fi

		if [ -z "${DLCI_NUM[$num]}" -a $PROTOCOL = WAN_FR ]; then
			error "DLCI_NUM" $num
			return 1
		fi

		if [ -z "${X25_ADDR[$num]}" -a $PROTOCOL = WAN_X25 ]; then
			error "X25_ADDR" $num
			return 1
		fi
	done

	num=0
	while [ $num -ne $NUM_OF_INTER ];
	do
		num=$((num+1))
		if [ -z "${INTR_STATUS[$num]}" ]; then
			error "INTR_STATUS" $num
			return 1
		fi

		if [ $PROTOCOL = WAN_X25 ]; then
			if [ "${PROT_STATUS[$num]}" = Unconfigured -a  ${CH_TYPE[$num]} = SVC ];
			then
				error "PROT_STATUS" $num
				return 1
			fi
		fi
	done

	num=0
	while [ $num -ne $NUM_OF_INTER ];
	do

		num=$((num+1))

		if [ ${OP_MODE[$num]} = API ]; then
			continue
		fi

		if [ -z "${IP_STATUS[$num]}" ]; then
			error "IP_STATUS" $num
			return 1
		fi
		if [ -z "${L_IP[$num]}" ]; then
			error "L_IP" $num
			return 1
		fi
		if [ -z "${R_IP[$num]}" ]; then
			error "R_IP" $num
			return 1
		fi
		if [ -z "${NMSK_IP[$num]}" ]; then
			error "NMSK_IP" $num
			return 1
		fi
	done

	

}

function parse_config_file () {

	local pvc_tst
	IFS="="
	ifnum=0
	num=0

	while read name value;
	do

		name=${name// /}

		#Convert to upper case
		name=`echo $name | tr a-z A-Z`

		value=${value%%#*}
		value=${value// /}
		case $name in 

		WANPIPE*) DEVICE_NUM=${name##WANPIPE}
			  PROTOCOL=`echo $value | cut -f1 -d ','`
			  case $PROTOCOL in
                          WAN_FR)
                                backtitle="WANPIPE Configuration Utility: Frame Relay Setup"
				firm_name="fr514.sfm"
                                ;;
                          WAN_CHDLC)
                                backtitle="WANPIPE Configuration Utility: CHDLC Setup"
				firm_name="cdual514.sfm"
                                ;;
                          WAN_PPP)
                                backtitle="WANPIPE Configuration Utility: PPP Setup"
				firm_name="ppp514.sfm"
                                ;;
			  WAN_X25)
				backtitle="WANPIPE Configuration Utility: X25 Setup"
				firm_name="x25_514.sfm"
				;;
				*)
				echo "Error in parsing $PROD_CONF/wanpipe$DEVICE_NUM.conf"
				echo "Illegal protocol : $PROTOCOL"
				cleanup
				exit 1
				;;
                          esac
	
			  #echo "DEVICE_NUM=$DEVICE_NUM"
			  #echo "Protocol = $PROTOCOL"
			  ;;
	#--------- Interface Definition --------------------
		WP*_*)    ifnum=$((ifnum+1))

			  #Conver to lower case
			  name=`echo $name | tr A-Z a-z`

			  IF_NAME[$ifnum]=$name
			  #echo "If_name $ifnum = ${IF_NAME[$ifnum]}"

			  if [ $PROTOCOL = WAN_FR ]; then
				DLCI_NUM[$ifnum]=`echo $value | cut -f2 -d ','`
				#echo "Dlci $ifnum = ${DLCI_NUM[$ifnum]}"
			  elif [ $PROTOCOL = WAN_X25 ]; then
				X25_ADDR[$ifnum]=`echo $value | cut -f2 -d ','`
				pvc_tst=${X25_ADDR[$ifnum]}
				pvc_tst=${pvc_tst%@*}
				pvc_tst=${pvc_tst// /}
				if [ -z $pvc_tst ]; then
					CH_TYPE[$ifnum]=SVC
				        X25_ADDR[$ifnum]=${X25_ADDR[$ifnum]/@/}
				else
					CH_TYPE[$ifnum]=PVC
					X25_ADDR[$ifnum]=$pvc_tst
				fi
				#echo "X25Addr $ifnum = ${X25_ADDR[$ifnum]}, Channel ${CH_TYPE[$ifnum]}"
			  fi

			  OP_MODE[$ifnum]=`echo $value | cut -f3 -d ','`
			  if [ ${OP_MODE[$ifnum]} = API ]; then
				INTR_STATUS[$ifnum]=setup;
			  fi
			  #echo "Operation Mode = ${OP_MODE[$ifnum]}"
			  NUM_OF_INTER=$ifnum
			  ;; 
	#-----------Hardware Setup ---------------------
		S514CPU*) S514CPU=$value
			  DEVICE_TYPE="S514"
			  #echo "S514CPU=$S514CPU" 
			  ;;
		PCISLOT*) PCISLOT=$value
			  #echo "PCISLOT=$PCISLOT" 
			  ;;
		IOPORT*)  IOPORT=$value
			  DEVICE_TYPE="S508"
			  #echo "IOPORT=$IOPORT"
			  ;;
		IRQ*)	  IRQ=$value
			  #echo "IRQ=$IRQ"
			  ;;
		FIRMWARE*) FIRMWARE=${value%/*}
			  #echo "FIRMWARE=$FIRMWARE" 
			  ;;
		MEMADDR*) MEMORY=${value%/*}
			  #echo "MEMORY=$MEMORY"
			  ;;
		INTERFACE*)INTERFACE=$value
			  #echo "INTERFACE=$INTERFACE" 
			  ;;
		NUMBER_OF_DLCI*)
			  NUMBER_OF_DLCI=$value
			  #echo "NUMBER_OF_DLCI=$NUMBER_OF_DLCI"
			  ;;
		CLOCKING*) CLOCKING=$value
			  #echo "CLOCKING=$CLOCKING" 
			  ;;
		BAUDRATE*) BAUDRATE=$value
			  #echo "BAUDRATE=$BAUDRATE" 
			  ;;
		MTU*)	  MTU=$value
			  #echo "MTU=$MTU" 
			  ;;
		UDPPORT*) UDPPORT=$value
			  #echo "UDPPORT=$UDPPORT" 
			  ;;
		STATION*) STATION=$value
			  #echo "STATION=$STATION" 
			  ;;
		SIGNALLING*) SIGNAL=$value
			    #echo "SIGNAL=$SIGNAL" 
			  ;;
		T391*)	  T391=$value
			  #echo "T391=$T391" 
			  ;;
		T392*)	  T392=$value
			  #echo "T392=$T392" 
			  ;;
		N391*)	  N391=$value
			  #echo "N391=$N391" 
			  ;;
		N392*)	  N392=$value
			  #echo "N392=$N392"
			  ;;
		N393*) 	  N393=$value
			  #echo "N393=$N393" 
			  ;;
		TTL*)	  TTL=$value
			  #echo "TTL=$TTL" 
			  ;;
		IP_MODE*) IPMODE=$value
			  #echo "IPMODE=$IPMODE"
			  ;;
		COMMPORT*) COMMPORT=$value
			  #echo "COMMPORT=$COMMPORT"
			  ;;
		RECEIVE_ONLY*) REC_ONLY=$value
			  ;;	
		LOWESTPVC*) LOW_PVC=$value
			  #echo "LOWESTPVC=$LOW_PVC"
			  ;;
		HIGHESTPVC*) HIGH_PVC=$value
			  #echo "HIGHESTPVC=$HIGH_PVC"
			  ;;
		LOWESTSVC*) LOW_SVC=$value
			  #echo "LOWESTSVC=$LOW_SVC"
			  ;;
		HIGHESTSVC*) HIGH_SVC=$value
			  #echo "HIGHESTSVC=$HIGH_SVC"
			  ;;
		HDLCWINDOW*) HDLC_WIN=$value
			  #echo "HDLCWINDOW=$HDLC_WIN"
			  ;;
		PACKETWINDOW*) PACKET_WIN=$value 	
			  #echo "PACKETWINDOW=$PACKET_WIN"
			  ;;
		CCITTCOMPAT*) CCITT=$value
			  #echo "CCITTCOMPAT=$CCITT"
			  ;;
		LAPB_HDLC_ONLY*) LAPB_HDLC_ONLY=$value
			  #echo "LAPB_HDLC_ONLY=$LAPB_HDLC_ONLY"
			  ;;
		CALL_SETUP_LOG*) CALL_LOGGING=$value
			  #echo "CALL_SETUP_LOG=$CALL_LOGGING"
			  ;;
		T10_T20*)	X25_T10_T20=$value
			;;
		T11_T21*)	X25_T11_T21=$value
			;;
		T12_T22*)	X25_T12_T22=$value
			;;
		T13_T23*)	X25_T13_T23=$value
			;;
		T16_T26*)	X25_T16_T26=$value
			;;
		T16_T26*)	X25_T16_T26=$value
			;;
		T28*)	X25_T28=$value
			;;
		T1*)	X25_T1=$value
			;;
		T2*)	X25_T2=$value
			;;
		T4*)	X25_T4=$value
			;;
		N2*)	X25_N2=$value
			;;
		R10_R20*)	X25_R10_R20=$value
			;;
		R12_R22*)	X25_R12_R22=$value
			;;
		R13_R23*)	X25_R13_R23=$value
			;;
	
	#--------- Interface Setup ---------------------
		\[WP*_*\]*) 
			num=$((num+1))
			INTR_STATUS[$num]=setup
			PROT_STATUS[$num]="Setup Done"
			;;

		MULTICAST*) 
			MULTICAST[$num]=$value
			#echo "MULTICAST $num =${MULTICAST[$num]}"
			  ;;
		INARPINTERVAL*) 
			INARP_INT[$num]=$value
			#echo "INARPINTERVAL $num =${INARP_INT[$num]}"
			  ;;
		INARP*)   
			INARP[$num]=$value
			#echo "INARP $num =${INARP[$num]}"
			  ;;
		CIR*)  	CIR[$num]=$value
			#echo "CIR $num =${CIR[$num]}"
			  ;;
		BC*)	BC[$num]=$value
			#echo "BC $num =${BC[$num]}"
			  ;;
		BE*)	BE[$num]=$value	
			#echo "BE $num =${BE[$num]}"
			  ;;
		IGNORE_DCD*) 
			DCD[$num]=$value
			#echo "DCD $num =${DCD[$num]}"
			  ;;
		IGNORE_CTS*) 
			CTS[$num]=$value
			#echo "CTS $num =${CTS[$num]}"
			  ;;
		IGNORE_KEEP*)
			KEEP[$num]=$value	
			#echo "KEEP $num =${KEEP[$num]}"
			  ;;
		HDLC_STREAMING*) 
			STREAM[$num]=$value
			#echo "STREAM $num =${STREAM[$num]}"
			  ;;
		KEEPALIVE_TX_TIMER*)
			TXTIME[$num]=$value
			#echo "TXTIME $num =${TXTIME[$num]}"
			  ;;
		KEEPALIVE_RX_TIMER*)
			RXTIME[$num]=$value
			#echo "RXTIME $num =${RXTIME[$num]}"
			  ;;
		KEEPALIVE_ERR_MARGIN*)
			ERR[$num]=$value
			#echo "ERR $num =${ERR[$num]}"
			  ;;
		SLARP_TIMER*)
			SLARP[$num]=$value
			if [ ${SLARP[$num]} -eq 0 ]; then
				CHDLC_IPMODE[$num]=NO;
			else
				CHDLC_IPMODE[$num]=YES;
			fi
			#echo "SLARP $num =${SLARP[$num]}"
			  ;;
		PAP*)
			PAP[$num]=$value
			#echo "PAP $num =${PAP[$num]}"
			  ;;
		CHAP*)	
			CHAP[$num]=$value
			#echo "CHAP $num =${CHAP[$num]}"
			  ;;
		IPX*)
			IPX[$num]=$value
			#echo "IPX $num =${IPX[$num]}"
			  ;;
		NETWORK*)
			NETWORK[$num]=$value
			#echo "NETWORK $num =${NETWORK[$num]}"
			  ;;
		USERID*)
			USERID[$num]=$value
			#echo "USERID $num =${USERID[$num]}"
			  ;;
		PASSWD*)
			PASSWD[$num]=$value
			#echo "PASSWD $num =${PASSWD[$num]}"
			  ;;
		SYSNAME*)
			SYSNAME[$num]=$value
			#echo "SYSNAME $num =${SYSNAME[$num]}"
			  ;;
		IDLETIMEOUT*)
			IDLE_TIMEOUT[$num]=$value
			#echo "IDLETIMEOUT $num =${IDLE_TIMEOUT[$num]}"
			  ;;
		HOLDTIMEOUT*)
			HOLD_TIMEOUT[$num]=$value
			#echo "HOLDTIMEOUT $num =${HOLD_TIMEOUT[$num]}"
			  ;;
		*) 	#echo -e "\n\nNot found *$name*"
			;;
		esac

	done < $PROD_CONF/wanpipe$DEVICE_NUM.conf 

	#------ IP Configuration ------------

	#echo "Num or interface is $NUM_OF_INTER"

	num=0
	while [ $num -ne $NUM_OF_INTER ]; 
	do 
		num=$((num+1))

		if [ ! -f "$INTERFACE_DIR/ifcfg-${IF_NAME[$num]}" ];
		then 
			if [ ${OP_MODE[$num]} = WANPIPE ]; then
				echo "File not found $INTERFACE_DIR/ifcfg-${IF_NAME[$num]}"  
			fi
			continue
		fi

		IP_STATUS[$num]="Setup Done"		

		while read name value; 
		do

		case $name in

		IPADDR) 
			L_IP[$num]=$value
			#echo "L_IP=${L_IP[$num]}"
			  ;;
		NETMASK)
			NMSK_IP[$num]=$value
			#echo "NMSK_IP=${NMSK_IP[$num]}"
			  ;;
		POINTOPOINT|REMIP)
			R_IP[$num]=$value
			#echo "R_IP=${R_IP[$num]}"
			  ;;
		BROADCAST)
			BCAST_IP[$num]=$value
			#echo "BCAST_IP=${BCAST_IP[$num]}"
			  ;;
		NETWORK)
			NETWRK_IP[$num]=$value
			if [ ${NETWRK_IP[$num]} = 0 ]; then
				DEFAULT_IP[$num]=YES
			else
				DEFAULT_IP[$num]=NO
				NETWRK_IP[$num]=" "
			fi
			#echo "NETWRK_IP=${NETWRK_IP[$num]}"
			  ;;
		GATEWAY)
			GATE_IP[$num]=$value
			#echo "GATE_IP=${GATE_IP[$num]}"
			  ;;
		esac

		done < $INTERFACE_DIR/ifcfg-${IF_NAME[$num]}
	done

	IFS=" "

}

function save_configuration () {

	local date=`date`
	WAN_CONFIG=$PROD_CONF/wanpipe$DEVICE_NUM.conf

	cat <<EOM > $WAN_CONFIG

#================================================
# WANPIPE$DEVICE_NUM Configuration File
#================================================
#
# Date: $date
#
# Note: This file was generated automatically
#       by /usr/lib/wanrouter/wancfg program.
#
#       If you want to edit this file, it is
#       recommended that you use wancfg program
#       to do so.
#================================================
# Sangoma Technologies Inc.
#================================================

EOM

	# -------------- [device] Area --------------------

	echo "[devices]" >> $WAN_CONFIG
	echo "wanpipe$DEVICE_NUM = $PROTOCOL, Comment" 	>> $WAN_CONFIG

	# -------------- [interface] Area -----------------


	echo -e "\n[interfaces]" 			>> $WAN_CONFIG
	if_num=0
	while [ $if_num -ne $NUM_OF_INTER ]; 
	do 
		if_num=$((if_num+1))

		if [ $PROTOCOL = WAN_X25 ]; then
			if [ ${CH_TYPE[$if_num]} = PVC ]; then
				DLCI_NUM[$if_num]="${X25_ADDR[$if_num]}"
			else
		 		DLCI_NUM[$if_num]="@${X25_ADDR[$if_num]}"
			fi
		fi

		echo "${IF_NAME[$if_num]} = wanpipe$DEVICE_NUM, ${DLCI_NUM[$if_num]}, ${OP_MODE[$if_num]}, Comment"				  >> $WAN_CONFIG 	
	done

	# -------------- [wanpipe#] Area -------------------

	echo -e "\n[wanpipe$DEVICE_NUM]" 		>> $WAN_CONFIG
	if [ $DEVICE_TYPE = S514 ]; then
		echo "S514CPU 	= $S514CPU" 		>> $WAN_CONFIG
		echo "PCISLOT 	= $PCISLOT" 		>> $WAN_CONFIG
	else
		echo "IOPORT 		= $IOPORT" 	>> $WAN_CONFIG
		echo "IRQ 		= $IRQ" 	>> $WAN_CONFIG
	fi
	echo "Firmware	= $FIRMWARE/$firm_name" 	>>$WAN_CONFIG
	if [ -z "$MEMORY" ]; then
		MEMORY=Auto
	fi
	if [ $MEMORY != Auto ]; then 
		echo "MemAddr		= $MEMORY" 	>> $WAN_CONFIG
	fi
	if [ $PROTOCOL = WAN_CHDLC ]; then
		echo "CommPort	= $COMMPORT" 		>> $WAN_CONFIG
		echo "Receive_Only	= $REC_ONLY"	>> $WAN_CONFIG
	fi
	echo "Interface 	= $INTERFACE" 		>> $WAN_CONFIG
	echo "Clocking 	= $CLOCKING" 			>> $WAN_CONFIG
	echo "BaudRate 	= $BAUDRATE" 			>> $WAN_CONFIG
	echo "MTU 		= $MTU" 		>> $WAN_CONFIG
	echo "UDPPORT 	= $UDPPORT" 			>> $WAN_CONFIG
	if [ $PROTOCOL = WAN_FR ]; then
		echo "NUMBER_OF_DLCI 	= $NUM_OF_INTER" >> $WAN_CONFIG
		echo "Station 	= $STATION" 		>> $WAN_CONFIG
		echo "Signalling 	= $SIGNAL" 	>> $WAN_CONFIG
		echo "T391 		= $T391" 	>> $WAN_CONFIG
		echo "T392 		= $T392" 	>> $WAN_CONFIG
		echo "N391 		= $N391" 	>> $WAN_CONFIG
		echo "N392 		= $N392" 	>> $WAN_CONFIG
		echo "N393 		= $N393" 	>> $WAN_CONFIG
	fi
	if [ $PROTOCOL = WAN_PPP ]; then
		echo "IP_MODE		= $IPMODE" 	>> $WAN_CONFIG
	fi
	if [ $PROTOCOL = WAN_X25 ]; then
		echo "Station		= $STATION" 		>> $WAN_CONFIG	
		echo "LowestPVC	= $LOW_PVC"		>> $WAN_CONFIG
		echo "HighestPVC 	= $HIGH_PVC"		>> $WAN_CONFIG
		echo "LowestSVC 	= $LOW_SVC"		>> $WAN_CONFIG
		echo "HighestSVC	= $HIGH_SVC"		>> $WAN_CONFIG
		echo "HdlcWindow	= $HDLC_WIN"		>> $WAN_CONFIG
		echo "PacketWindow	= $PACKET_WIN"		>> $WAN_CONFIG
		echo "CCITTCompat	= $CCITT"		>> $WAN_CONFIG
		echo "X25Config	= 0x0090"		>> $WAN_CONFIG
		echo "LAPB_HDLC_ONLY	= $LAPB_HDLC_ONLY"	>> $WAN_CONFIG
		echo "CALL_SETUP_LOG 	= $CALL_LOGGING"	>> $WAN_CONFIG
		echo "T1		= $X25_T1"		>> $WAN_CONFIG
		echo "T2		= $X25_T2"		>> $WAN_CONFIG
		echo "T4		= $X25_T4"		>> $WAN_CONFIG
		echo "N2		= $X25_N2"		>> $WAN_CONFIG
		echo "T10_T20		= $X25_T10_T20"		>> $WAN_CONFIG
		echo "T11_T21		= $X25_T11_T21"		>> $WAN_CONFIG
		echo "T12_T22	 	= $X25_T12_T22"		>> $WAN_CONFIG
		echo "T13_T23		= $X25_T13_T23"		>> $WAN_CONFIG
		echo "T16_T26		= $X25_T16_T26"		>> $WAN_CONFIG
		echo "T16_T26		= $X25_T16_T26"		>> $WAN_CONFIG
		echo "T28		= $X25_T28"		>> $WAN_CONFIG
		echo "R10_R20		= $X25_R10_R20"		>> $WAN_CONFIG
		echo "R12_R22		= $X25_R12_R22"		>> $WAN_CONFIG
		echo "R13_R23		= $X25_R13_R23"		>> $WAN_CONFIG
	fi

	echo "TTL 		= $TTL" 		>> $WAN_CONFIG


	#--------- [wp#_<protocol>] area ----------------------------
			

	if_num=0
	while [ $if_num -ne $NUM_OF_INTER ];
	do
		if_num=$((if_num+1))

		case  $PROTOCOL in

		WAN_FR)
			echo >> $WAN_CONFIG
			echo "[${IF_NAME[$if_num]}]" >> $WAN_CONFIG
			if [ -z "${CIR[$if_num]}" ]; then
				CIR[$if_num]=NO
			fi
			if [ ${CIR[$if_num]} != NO ]; then
				echo "CIR 		= ${CIR[$if_num]}" >> $WAN_CONFIG
				echo "BC  		= ${BC[$if_num]}" >> $WAN_CONFIG
				echo "BE  		= ${BE[$if_num]}" >> $WAN_CONFIG
			fi
			echo "MULTICAST 	= ${MULTICAST[$if_num]}" >> $WAN_CONFIG
			echo "INARP 		= ${INARP[$if_num]}" >> $WAN_CONFIG
			echo "INARPINTERVAL 	= ${INARP_INT[$if_num]}" >> $WAN_CONFIG
			;;
		WAN_PPP)
			echo >> $WAN_CONFIG
			echo "[${IF_NAME[$if_num]}]" 		>> $WAN_CONFIG	
			echo "MULTICAST 	= ${MULTICAST[$if_num]}">> $WAN_CONFIG
			echo "PAP       	= ${PAP[$if_num]}" 	>> $WAN_CONFIG
			echo "CHAP		= ${CHAP[$if_num]}" 	>> $WAN_CONFIG
			echo "IPX		= ${IPX[$if_num]}" 	>> $WAN_CONFIG
			if [ ${IPX[$if_num]} = YES ]; then
				echo "NETWORK		= ${NETWORK[$if_num]}"  >> $WAN_CONFIG
			fi

			if [ ${PAP[$if_num]} = YES -o ${CHAP[$if_num]} = YES ]; then
				echo "USERID 	= ${USERID[$if_num]}" 	>> $WAN_CONFIG
				echo "PASSWD   	= ${PASSWD[$if_num]}" 	>> $WAN_CONFIG
				echo "SYSNAME  	= ${SYSNAME[$if_num]}" 	>> $WAN_CONFIG
			fi
			;;
		WAN_CHDLC)
			echo >> $WAN_CONFIG
			echo "[${IF_NAME[$if_num]}]" 			>> $WAN_CONFIG	
			echo "MULTICAST		= ${MULTICAST[$if_num]}">> $WAN_CONFIG
			echo "IGNORE_DCD		= ${DCD[$if_num]}" 	>> $WAN_CONFIG
			echo "IGNORE_CTS		= ${CTS[$if_num]}" 	>> $WAN_CONFIG
			echo "IGNORE_KEEPALIVE	= ${KEEP[$if_num]}" 	>> $WAN_CONFIG
			echo "HDLC_STREAMING		= ${CTS[$if_num]}" 	>> $WAN_CONFIG
			echo "KEEPALIVE_TX_TIMER	= ${TXTIME[$if_num]}" 	>> $WAN_CONFIG
			echo "KEEPALIVE_RX_TIMER	= ${RXTIME[$if_num]}" 	>> $WAN_CONFIG
			echo "KEEPALIVE_ERR_MARGIN	= ${ERR[$if_num]}"	>> $WAN_CONFIG
			echo "SLARP_TIMER		= ${SLARP[$if_num]}"	>> $WAN_CONFIG
			;;
		WAN_X25)
			if [ ${CH_TYPE[$if_num]} = SVC ]; then
				echo >> $WAN_CONFIG
				echo "[${IF_NAME[$if_num]}]" 		>> $WAN_CONFIG	
				echo "IdleTimeout 	= ${IDLE_TIMEOUT[$if_num]}" >> $WAN_CONFIG
				echo "HoldTimeout 	= ${HOLD_TIMEOUT[$if_num]}" >> $WAN_CONFIG
			fi
			;;
		*)
			;;
		esac
		
	done		


	if_num=0
	while [ $if_num -ne $NUM_OF_INTER ];
	do
		if_num=$((if_num+1))

		if [ ${OP_MODE[$if_num]} = API ]; then
			continue
		fi	

		date=`date`

		cat <<EOM > $INTERFACE_DIR/ifcfg-${IF_NAME[$if_num]}
#!/bin/sh
# Wanrouter interface configuration file
# name:	${IF_NAME[$if_num]}
# date:	$date
#
ONBOOT=yes
DEVICE=${IF_NAME[$if_num]}
IPADDR=${L_IP[$if_num]}
NETMASK=${NMSK_IP[$if_num]}
REMIP=${R_IP[$if_num]}
BROADCAST=${BCAST_IP[$num]}
NETWORK=${NETWRK_IP[$if_num]}
GATEWAY=${GATE_IP[$num]}
EOM

	done


}
